\keyword{ts}
\keyword{arith}
\name{its-arith}
\alias{its-arith}
\alias{Arith,its,its-method}
\alias{+}

\title{Arithmetic Methods for Irregular Time-Series Objects}
\description{
  Arithmetic methods for objects of class \code{"its"}.
}

\usage{
     x + y
     x - y
     x * y
     x / y
     x ^ y
     x %% y
     x %/% y
}

\arguments{
  \item{x,y}{an object of class \code{"its"}}
}
\details{

The arithmetic operators return numeric vectors containing the result of the 
element-by-element operations.  The arguments must be conformable (same dimensions) 
and their time-stamps must match for each row.

Note that the matrix multiplication operator, %*%, is inherited from matrix,
and the result of a matrix multiplication is a matrix, not an \code{"its"}.
The resulting matrix can be converted back to its using the function its() 
- see examples.
}

\value{

The returned object is an object of class \code{"its"}, conformable with the
inputs, and with identical time-stamps.

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
}

\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
b+b-2*b
b/b
b%*%diag(ncol(b))
its(b%*%diag(ncol(b))) 
}
}
\eof
\keyword{ts}
\name{its-cumdif}
\alias{its-cumdif}
\alias{cumsum,its-method}
\alias{diff,its-method}

\title{Cumulation, Differencing for Irregular Time-Series Objects}
\description{
  Cumulation, differencing for objects of class \code{"its"}.
}
\section{Usage}{

cumsum(x)
diff(x,lag=1)

}
\section{Arguments}{
\describe{
  \item{x}{an object of class \code{"its"}}
  \item{lag}{an integer number of lags}
  }
}

\details{

\code{cumsum} and \code{diff} perform the cumulative sum and difference of each
column in turn.  In \code{diff}, the first \code{lag} rows are discarded.

}

\value{

An object of class \code{"its"}

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}

\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
cumsum(b)
diff(b,lag=2)
}
}
\eof
\keyword{ts}
\name{its-def}

\alias{its}
\alias{its-class}
\alias{is.its}
\alias{as.its}
\alias{its.format}

\title{Irregularly Spaced Time-Series}

\description{
  The function \code{its} is used to create irregular time-series
  objects.
  \code{as.its} coerces an object to an irregularly spaced
  time-series. \code{is.its} tests whether an object is an irregularly
  spaced time series.
  }

\usage{
its(x,dates=as.POSIXct(x=strptime(dimnames(x)[[1]],format=its.format())),
names=dimnames(x)[[2]],format=its.format(),...)
as.its(x,...)
is.its(object)
its.format(format=NULL)
}

\arguments{
  \item{dates}{a vector of class \code{"POSIXct"}
    representing the time-stamps of the irregular time-series
    object. The elements of the numeric vector are construed as the
    number of seconds since the beginning of 1970, see
    \code{\link{POSIXct}}.}
  \item{x}{a numeric matrix representing the values of the
    irregular time-series object.  In the case of coercion, the first
    column is taken to be the time-stamps, in seconds since the beginning
    of 1970, see \code{\link{POSIXct}}.}
  \item{object}{an irregular time-series object}
  \item{names}{a vector of mode character}
  \item{format}{a formatting string, see \code{\link{format.POSIXct}},
    defaults to \code{"\%Y-\%m-\%d"} if \code{format} is not specified.}
  \item{\dots}{further arguments passed to or from other methods:
    for \code{its} passed to \code{\link{format.POSIXct}}.;
    for \code{as.its} passed to \code{\link{its}}}
}

\details{
 The function its is used to create irregular time-series ("its") objects.
 An object of class "its" is a matrix with rows indexed by a time-stamp
 of class "POSIXct". Unlike objects of class "ts", it can be used to
 represent irregularly spaced time-series.  The object consists of a
 matrix, with a single slot, the named POSIX vector named "dates".
 An object of class its inherits matrix arithmetic methods.  The matrix
 has dimnames: dimnames[[1]] is populated with a text representation of
 "dates", using a format which is defined by the function its.format. These
 text dates are not used in computations - all computations use the 
 POSIX representation.  The dates are required to be in ascending order.
 
 When matrix multiplication is applied to an "its", the result is of class
 matrix.  It is possible to restore the "its" class (see examples) - its() 
 is in this sense idempotent i.e. its(mat)==its(its(mat)).

 its.format returns a formatting string, and assigns a format variable
 \code{its..format} globally, which persists in the session until reset.

}

\value{
For \code{its} and \code{as.its}, an object of class \code{"its"}, inheriting
from matrix, with a single slot named \code{'dates'}, which is a vector of
class \code{POSIXct}

For \code{is.its}, a logical representing the result of a test for class membership

For \code{its.format}, a text representation of dates formatting for dimnames,
see \code{\link{format.POSIXct}}

}

\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
  }

\examples{
\dontrun{
its.format("\%Y-\%m-\%d")    #defines text format of dates read from dimnames
mat <- structure(1:6,dim=c(2,3),dimnames=list(c("2003-01-01","2003-01-04"),letters[1:3]))
its(mat)
its.format("\%Y\%m\%d")    #defines text format of dates written to dimnames
times <- as.POSIXct(strptime(c("1999-12-31 01:00:00","2000-01-01 02:00:00"),format="\%Y-\%m-\%d \%X"))
its(mat,times)
its.format("\%Y-\%m-\%d \%X")
its(mat,times)
is.its(its(mat,times))
its.format("\%Y\%m\%d \%X")   #defines text format of dates written to dimnames
as.its(mat)
}
}
\eof
\keyword{ts}
\name{its-disp}
\alias{its-disp}
\alias{plot,its,missing-method}
\alias{print,its-method}

\title{Display Methods for Irregular Time-Series Objects}
\description{
  Display methods for objects of class \code{"its"}.
}

\section{Usage}{
plot(x,y,colvec=1:ncol(x),type="l",ltypvec=1,lwdvec=1,
leg=FALSE,yrange,format,at,interp=c("linear","none"),...)
print(x,...)
}

\section{Arguments}{
\describe{
  \item{x}{an object of class \code{"its"}}
  \item{y}{missing}
  \item{type}{plot type, "l" for line, "p" for point, "b" for both - see \code{\link{par}}.}
  \item{colvec,ltypvec,lwdvec}{vectors of colour codes, line types, and line widths: see \code{\link{par}}.}
  \item{leg}{logical flag to display legend; uses \code{locator} for position.}
  \item{yrange}{ordinate range for display.}
  \item{format}{a formatting string, see \code{\link{format.POSIXct}}, for the axis dates}
  \item{at}{a vector of POSIX dates defining tickmark locations on axis: see \code{\link{axis.POSIXct}}}
  \item{\dots}{further arguments passed to or from other methods:
    for \code{plot} passed to \code{\link{plot}}.;
    for \code{print} passed to \code{\link{print.matrix}}}
    }
}
\details{

\code{plot} is the method for plotting irregular time-series objects.
All series are displayed on a single set of axes, by default using different
colours, linetypes, and widths.  If the vectors defining these attributes are 
short, they are cycled.

\code{print} is the method for printing irregular time-series objects.
The format for the dates is determined at the time the 'its' object is created.

}

\value{

The methods are called for their side-effects.

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}

\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
plot(b,colvec=c(1,7),lwdvec=1:2,ltypvec=1:2)
print(b)
its.format("\%d/\%m/\%Y")
b <- as.its(a)
print(b)
}
}
\eof
\keyword{ts}
\name{its-file}
\alias{its-file}
\alias{readcsvIts}
\alias{writecsvIts}
\title{File Operations for Irregular Time-Series Objects}
\description{
  File read and write operations for objects of class \code{"its"}.
}
\usage{
readcsvIts(filename,informat=its.format(),outformat=its.format(),tz="",
usetz=FALSE,header=TRUE,...)
writecsvIts(x,filename,format=its.format(),tz="",usetz=FALSE,col.names=NA,
sep=",",...)
}
\arguments{
  \item{filename}{filename}
  \item{x}{an object of class \code{"its"}}
  \item{format, informat, outformat, tz, usetz}{formatting related arguments, see \code{\link{format.POSIXct}}.}
  \item{header}{see \code{\link{read.csv}}}
  \item{col.names, sep}{see \code{\link{write.table}}}
  \item{\dots}{further arguments passed to or from other methods: for
    \code{readcsvIts} passed to \code{\link{read.csv}}; for
    \code{writecsvIts} passed to \code{\link{write.table}}}
}
\details{
  \code{readcsvIts} reads from a .csv file to a matrix.  The first column is assumed to
  contain dates in text format specified by informat, which can optionally be
  reformatted into the text format outformat.  Both of these formats default to the
  format specified by \code{\link{its.format}}.  To convert the matrix to an its, use 
  \code{\link{its}} (see example)

  \code{writecsvIts} write an irregular time-series object to a text file.
}
\value{

  For \code{readcsvIts} a matrix

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}
\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
fname <- tempfile()
# To write an irregular time-series object to a file one might use
writecsvIts(b,filename=fname)
# To read an irregular time-series object from a file one might use
its(readcsvIts(filename=fname))
unlink(fname)
}
}
\eof
\keyword{ts}
\name{its-fin}
\alias{its-fin}
\alias{accrueIts}
\title{Financial Functions for Irregular Time-Series Objects}
\description{
  Financial functions for objects of class \code{"its"}.
}
\usage{
accrueIts(x,daysperyear=365)
}
\arguments{
  \item{x}{an object of class \code{"its"}}
  \item{daysperyear}{integer, representing days per year for accrual}
}
\details{
  \code{accrueIts} Accrues an annual rate stored in x, expressed as a
  decimal (not a percentage), based on the difference of the time-stamps.
  The accrued value is not cumulated, it is a per-period return.
}
\value{

  An object of class \code{"its"}

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}
\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
accrueIts(b[which(weekdayIts(b)),]/100,daysperyear=365)
}
}
\eof
\keyword{ts}
\name{its-info}
\alias{its-info}
\alias{start,its-method}
\alias{end,its-method}
\alias{summary,its-method}

\title{Summary Information for Irregular Time-Series Objects}
\description{
  Summary information for objects of class \code{"its"}.
}
\section{Usage}{

start(x,format=its.format(),\dots)
end(x,format=its.format(),\dots)
summary(object)

}
\section{Arguments}{
\describe{
  \item{x, object}{an object of class \code{"its"}}
  \item{format}{a formatting string, see \code{\link{format.POSIXct}}}
  \item{\dots}{further arguments passed to or from other methods:
    for \code{start} and \code{end}, passed to \code{\link{format.POSIXct}.} }
    }
}
\details{

Summary returns the mean, standard deviation, minimum, maximum, and number of
non-NA data points for each series.

Start and end return the dates corresponding to the first and last rows,
respectively.

}

\value{

For \code{start}, \code{end}, a formatted text representation of the first and last times
For \code{summary}, a table of summary statistics for each series
}

\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}

\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
start(b,format="\%y-\%m-\%d")
end(b)
summary(b)
}
}
\eof
\keyword{internal}
\name{its-internal}
\alias{addDimnames}
\alias{gapIts}
\alias{overlapsIts}
\alias{overlapmatchesIts}
\alias{namesmatchIts}
\alias{expandIts}
\alias{plotIts}
\alias{printIts}
\alias{startIts}
\alias{endIts}
\alias{summaryIts}
\alias{cumsumIts}
\alias{diffIts}
\alias{validIts}
\alias{unionIts}
\alias{intersectIts}

\title{Internal Functions for Irregular Time-Series Objects}
\description{
  Internal functions for objects of class \code{"its"}.
}
\usage{

addDimnames(mat)
gapIts(x,y,maxgap)
overlapsIts(x,y)
overlapmatchesIts(x,y)
namesmatchIts(x,y)
expandIts(x)
plotIts(x,y,colvec=1:ncol(x),type="l",ltypvec=1,lwdvec=1,
       leg=FALSE,yrange,format,at,interp=c("linear","none"),...)
printIts(x,...)
startIts(x,format=its.format(),...)
endIts(x,format=its.format(),...)
summaryIts(object,...)
cumsumIts(x)
diffIts(x,lag=1)
validIts(object)
unionIts(x,y)
intersectIts(x,y)

}
\arguments{
  \item{mat}{a matrix}
  \item{x,y,object,e1,e2}{objects of class \code{"its"}}
  \item{maxgap}{a numeric scalar}
  \item{type}{plot type, see \code{\link{par}}.}
  \item{colvec,ltypvec,lwdvec}{vectors of colour codes, line types, and line widths: see \code{\link{par}}.}
  \item{leg}{logical flag to display legend; uses \code{locator} for position.}
  \item{yrange}{ordinate range for display.}
  \item{at}{a vector of POSIX dates defining tickmark locations on axis: see \code{\link{axis.POSIXct}}}
  \item{format}{a formatting string, see \code{\link{format.POSIXct}}, for the axis dates}
  \item{\dots}{further arguments passed to or from other methods:
    for \code{start} and \code{end}, passed to \code{\link{format.POSIXct}.} }
    for \code{plot} passed to \code{\link{plot}}.;
    for \code{print} passed to \code{\link{print.matrix}}
  \item{lag}{an integer number of lags}
}

\details{

These functions are utilities, not intended for general use.
addDimnames adds dimnames (strings representing row and column number) if absent
gapIts tests for the present of a gap in the time-stamps of its inputs
overlapsIts tests for the presence of overlap in the time-stamps of its inputs
overlapmatchesIts tests for equality of overlapping data in its inputs
namesmatchIts tests for equality of column names of its inputs
expandIts splits a single series into a number of series, each with a single run of non-NA data.
Other functions are the \code{setMethod} \code{definition} for the associated generic.
}

\value{

addDimnames returns a matrix
gapIts returns the gap (in seconds) between inputs
overlapsIts returns a boolean
overlapmatchesIts returns a boolean
namesmatchIts returns a boolean
for other functions, refer to the associated generic
}
\author{Giles Heywood}

\seealso{
  \code{\link{its}},
}
\eof
\keyword{ts}
\name{its-join}
\alias{its-join}
\alias{union}
\alias{union,its,NULL-method}
\alias{union,NULL,its-method}
\alias{union,its,its-method}
\alias{intersect}
\alias{intersect,its,NULL-method}
\alias{intersect,NULL,its-method}
\alias{intersect,its,its-method}
\alias{alignedIts}
\alias{appendIts}

\title{Join Functions for Irregular Time-Series Objects}
\description{
  Join functions for objects of class \code{"its"}.
}
\usage{
union(x,y)
intersect(x,y)
alignedIts(obj1,obj2,print=TRUE)
appendIts(obj1,obj2,but=TRUE,matchnames=TRUE)
}

\arguments{
  \item{x, y}{an object of class \code{"its"} or NULL}
  \item{obj1, obj2}{an object of class \code{"its"}}
  \item{print}{logical flag to display summary information}
  \item{but}{logical flag controls whether overlap is disallowed}
  \item{matchnames}{logical flag controls whether names must match}
}

\details{

\code{union} has a number of time values (rows) which is determined by the union
of the time-stamps of the two inputs.  The number of columns is the sum of the
number of columns of the two inputs.

\code{intersect} has a number of time values (rows) which is determined by the
intersect of the time-stamps of the two inputs.  The number of columns is the sum
of the number of columns of the two inputs.

\code{alignedIts} selects the rows from two inputs which have identical time-stamps

\code{appendIts} appends one object to the other, removing overlapping data from the
later object, optionally checking that the column names match

}

\value{
For \code{union}, \code{intersect}, \code{appendIts} an object of class \code{"its"}.

For \code{alignedIts}, a list of two objects of class \code{"its"}
}

\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}

\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
union(b,diff(b))
intersect(b,diff(b))
alignedIts(b,diff(b))
a1 <- matrix(c(seq(from=24*60*60*30,by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b1 <- as.its(a1)
appendIts(b,b1)
}
}
\eof
\keyword{ts}
\name{its-lags}
\alias{its-lags}
\alias{lagIts}
\alias{lagdistIts}
\title{Lag Functions for Irregular Time-Series Objects}
\description{
  Lag functions for objects of class \code{"its"}.
}
\usage{
lagIts(x,k=1)
lagdistIts(x,kmin,kmax)
}
\arguments{
  \item{x}{an object of class \code{"its"}}
  \item{k, kmin, kmax}{integer lag; positive value mean earlier data is
    assigned to a later timestamp}
}
\details{
  \code{lagIts} returns an object with the same time-stamps, but with the data shifted.
  \code{lagdistIts} applies lagIts over a range of lags, and appends these columns
}
\value{

  An object of class \code{"its"}.

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}

\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
lagIts(b)
lagdistIts(b[,1],1,3)
}
}
\eof
\keyword{ts}
\name{its-subset}
\alias{its-subset}
\alias{rangeIts}
\alias{x[i,j]}
\alias{[,its-method}
\title{Range and Extract for Irregular Time-Series Objects}
\description{
  Range and extratct for objects of class \code{"its"}.
}
\usage{
rangeIts(x,start=startIts(x),end=endIts(x),format=its.format(),...)
x[i,j]
}
\arguments{
  \item{x}{an object of class \code{"its"}}
  \item{start, end}{text representing start and end dates of the range to extract}
  \item{format}{format of \code{"start"} and \code{"end"} dates, see
        \code{\link{format.POSIXct}}.}
  \item{i,j}{indices specifying the parts to be extracted from the irregular
        time-series object}
  \item{\dots}{further arguments passed to \code{\link{as.POSIXct}}}
}
\details{
  \code{rangeIts} selects a range of rows that fall between two times, specified
  in text format.

  \code{x[i,j]} extractor method for an irregular time-series proceeds as for a matrix, with
  the exception that drop=FALSE is enforced, so the result always inherits from matrix.
}
\value{

  An object of class \code{"its"}.

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}

\examples{
\dontrun{
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
rangeIts(b,start = "1970-01-04" ,end= "1970-01-06" ,format= "\%Y-\%m-\%d" )
b[1:3,]
b[,1]
}
}
\eof
\keyword{ts}
\name{its-times}
\alias{its-times}
\alias{daysecondIts}
\alias{weekdayIts}
\title{Time Functions for Irregular Time-Series Objects}
\description{
  Time functions for objects of class \code{"its"}.
}
\usage{
daysecondIts(x,...)
weekdayIts(x,...)
}

\arguments{
  \item{x}{an object of class \code{"its"}}
  \item{\dots}{further arguments passed to \code{\link{as.POSIXlt}}}
}

\details{
  \code{daysecondIts} returns the number of seconds since midnight.

  \code{weekdayIts} tests which entries of an  irregular time-series object are
  time-stamped with weekdays.

}

\value{

  For \code{daysecondIts} a vector of decimal numbers representing the number of seconds.

  For \code{weekdayIts}  a vector of \code{"logical"} representing the test results
  for each time.

}
\author{Giles Heywood}

\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{its-file}},
  \code{\link{its-lags}}
  \code{\link{its-join}}
  \code{\link{its-times}}
  \code{\link{its-subset}}
  \code{\link{its-fin}}
  \code{\link{its-disp}}
  \code{\link{its-info}}
  \code{\link{its-cumdif}}
  \code{\link{its-arith}}
}

\examples{
\dontrun{
its.format("\%Y-\%m-\%d \%A")
a <- matrix(c(seq(by=24*60*60,length=20),1:20,41:60),nrow=20,ncol=3)
b <- as.its(a)
print(b)
daysecondIts(b)
weekdayIts(b)
}
}
\eof
